| amp.dm-package | R Documentation |
Tools and functions to efficiently create datasets used in pharmacometric analysis. Additional functionality is added to create documentation and prepare files for submission and quality control purposes.
Maintainer: Richard Hooijmaijers richardhooijmaijers@gmail.com [copyright holder]
Other contributors:
LAPP Consultants info@lapp.nl [funder, copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.