attr_xls: Reads in attributes from an external excel file

View source: R/attr_xls.r

attr_xlsR Documentation

Reads in attributes from an external excel file

Description

This function reads in attributes available in an excel file and creates a structured list

Usage

attr_xls(xls, sepfor = "\n", nosort = FALSE)

Arguments

xls

character with the name of the excel file containing the attributes

sepfor

character of length 1 indicating what the separator for formats should be

nosort

logical indicating if sorting of variables should be omitted (otherwise sorting of no. column in excel file is applied)

Value

named list with the attributes

Author(s)

Richard Hooijmaijers

Examples

xmpl  <- system.file("example/Attr.Template.xlsx",package = "amp.dm")
head(attr_xls(xmpl),3)

amp.dm documentation built on March 13, 2026, 5:08 p.m.