cmnt_print: Function that prints the comments given by cmnt

View source: R/utils.R

cmnt_printR Documentation

Function that prints the comments given by cmnt

Description

Prints the results in markdown format to be used directly in inline coding

Usage

cmnt_print(clean = TRUE)

Arguments

clean

logical indicating if the comments should be deleted after printing (see details)

Details

The function returns a text string with the comments given up to the point it was called. When clean is set to TRUE (default), the content of the comment dataset is cleaned to overcome repetition of comments each time it is called

Value

character string with the comments

Author(s)

Richard Hooijmaijers

Examples

cmnt("Comment to print")
cmnt_print()

amp.dm documentation built on March 13, 2026, 5:08 p.m.