get_script: Get the current script name (either interactive Rstudio,...

View source: R/get_script.r

get_scriptR Documentation

Get the current script name (either interactive Rstudio, markdown or batch script)

Description

Get the current script name (either interactive Rstudio, markdown or batch script)

Usage

get_script(base = TRUE, noext = TRUE)

Arguments

base

logical indicating if the basename should be returned (without path)

noext

logical indicating if the file extension should be omitted

Value

character with the current script name

Author(s)

Richard Hooijmaijers


amp.dm documentation built on March 13, 2026, 5:08 p.m.