| attr_xls | R Documentation |
This function reads in attributes available in an excel file and creates a structured list
attr_xls(xls, sepfor = "\n", nosort = FALSE)
xls |
character with the name of the excel file containing the attributes |
sepfor |
character of length 1 indicating what the separator for formats should be |
nosort |
logical indicating if sorting of variables should be omitted (otherwise sorting of no. column in excel file is applied) |
named list with the attributes
Richard Hooijmaijers
xmpl <- system.file("example/Attr.Template.xlsx",package = "amp.dm")
head(attr_xls(xmpl),3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.