Learn R Programming

amp.dm (version 0.2.0)

attr_xls: Reads in attributes from an external excel file

Description

This function reads in attributes available in an excel file and creates a structured list

Usage

attr_xls(xls, sepfor = "\n", nosort = FALSE)

Value

named list with the attributes

Arguments

xls

character with the name of the excel file containing the attributes

sepfor

character of length 1 indicating what the separator for formats should be

nosort

logical indicating if sorting of variables should be omitted (otherwise sorting of no. column in excel file is applied)

Author

Richard Hooijmaijers

Examples

Run this code
xmpl  <- system.file("example/Attr.Template.xlsx",package = "amp.dm")
head(attr_xls(xmpl),3)

Run the code above in your browser using DataLab