powered by
This function reads in attributes available in an excel file and creates a structured list
attr_xls(xls, sepfor = "\n", nosort = FALSE)
named list with the attributes
character with the name of the excel file containing the attributes
character of length 1 indicating what the separator for formats should be
logical indicating if sorting of variables should be omitted (otherwise sorting of no. column in excel file is applied)
Richard Hooijmaijers
xmpl <- system.file("example/Attr.Template.xlsx",package = "amp.dm") head(attr_xls(xmpl),3)
Run the code above in your browser using DataLab