| check_nmdata | R Documentation |
This function checks if there are any common errors or mistakes within a NONMEM dataset, and reports the results back to console, table or dataframe
check_nmdata(
x,
type = 1,
ret = "tbl",
capt = NULL,
align = NULL,
size = "\\footnotesize",
...
)
x |
either a path to a CSV file or a data frame with the NONMEM data that should be checked |
type |
integer with the type of checks. Currently 1 can be used for checks that should all pass for a valid analysis and 2 for checks that trigger further investigation |
ret |
a character vector to define what kind of output should be returned (either "dfrm", "tbl", "file") |
capt |
character with the caption of the table (not used in case data frame is returned) |
align |
alignment of the table passed to general_tbl (not used in case data frame is returned) |
size |
character with font size as for the table general_tbl |
... |
additional arguments passed to general_tbl |
the checks are either printed, returned as dataframe or placed in a PDF
Richard Hooijmaijers
chkf <- system.file("example/NM.theoph.V1.csv",package = "amp.dm")
check_nmdata(chkf)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.