cmnt: Add comment to environment to present in documentation

View source: R/utils.R

cmntR Documentation

Add comment to environment to present in documentation

Description

Adds a comment regarding assumptions and special attention into package environment, which can be used in code chunks and easily printed after a code chunk

Usage

cmnt(string = "", bold = FALSE, verbose = TRUE)

Arguments

string

character of length one with the comment to add

bold

logical indicating if the string should be printed in bold to emphasize importance

verbose

logical indicating if the comment should be printed when function is called

Value

no return value, called for side effects

Author(s)

Richard Hooijmaijers

Examples

cmnt("Exclude time points > 12h")
cmnt("Subject 6 deviates and is excluded in the analysis", TRUE)
# Markdown syntax can be used for comments:
cmnt("We can use **bold** and *italic* or `code`")
# we can print the contents of the comments with
get_log()$cmnt_nfo

amp.dm documentation built on March 13, 2026, 5:08 p.m.