| cmnt | R Documentation |
Adds a comment regarding assumptions and special attention into package environment, which can be used in code chunks and easily printed after a code chunk
cmnt(string = "", bold = FALSE, verbose = TRUE)
string |
character of length one with the comment to add |
bold |
logical indicating if the string should be printed in bold to emphasize importance |
verbose |
logical indicating if the comment should be printed when function is called |
no return value, called for side effects
Richard Hooijmaijers
cmnt("Exclude time points > 12h")
cmnt("Subject 6 deviates and is excluded in the analysis", TRUE)
# Markdown syntax can be used for comments:
cmnt("We can use **bold** and *italic* or `code`")
# we can print the contents of the comments with
get_log()$cmnt_nfo
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.