Learn R Programming

amp.dm (version 0.2.0)

cmnt: Add comment to environment to present in documentation

Description

Adds a comment regarding assumptions and special attention into package environment, which can be used in code chunks and easily printed after a code chunk

Usage

cmnt(string = "", bold = FALSE, verbose = TRUE)

Value

no return value, called for side effects

Arguments

string

character of length one with the comment to add

bold

logical indicating if the string should be printed in bold to emphasize importance

verbose

logical indicating if the comment should be printed when function is called

Author

Richard Hooijmaijers

Examples

Run this code
cmnt("Exclude time points > 12h")
cmnt("Subject 6 deviates and is excluded in the analysis", TRUE)
# Markdown syntax can be used for comments:
cmnt("We can use **bold** and *italic* or `code`")
# we can print the contents of the comments with
get_log()$cmnt_nfo

Run the code above in your browser using DataLab