| cmnt_print | R Documentation |
Prints the results in markdown format to be used directly in inline coding
cmnt_print(clean = TRUE)
clean |
logical indicating if the comments should be deleted after printing (see details) |
The function returns a text string with the comments given up to the point it was called. When clean is set to TRUE (default), the content of the comment dataset is cleaned to overcome repetition of comments each time it is called
character string with the comments
Richard Hooijmaijers
cmnt("Comment to print")
cmnt_print()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.