Learn R Programming

amp.dm (version 0.2.0)

cmnt_print: Function that prints the comments given by cmnt

Description

Prints the results in markdown format to be used directly in inline coding

Usage

cmnt_print(clean = TRUE)

Value

character string with the comments

Arguments

clean

logical indicating if the comments should be deleted after printing (see details)

Author

Richard Hooijmaijers

Details

The function returns a text string with the comments given up to the point it was called. When clean is set to TRUE (default), the content of the comment dataset is cleaned to overcome repetition of comments each time it is called

Examples

Run this code
cmnt("Comment to print")
cmnt_print()

Run the code above in your browser using DataLab