define_tbl: Create define PDF file for submission of pharmacometric data...

View source: R/define_tbl.r

define_tblR Documentation

Create define PDF file for submission of pharmacometric data files

Description

This function creates the define.pdf file necessary for esubmission.

Usage

define_tbl(
  attr = NULL,
  ret = "dfrm",
  capt = "Dataset define form",
  align = "lp{3cm}lp{8cm}",
  outnm = NULL,
  orientation = "portrait",
  size = "\\footnotesize",
  src = NULL,
  ...
)

Arguments

attr

list with datasets attributes

ret

a character vector to define what kind of output should be returned (either "dfrm", "tbl", "file")

capt

character with the caption of the table

align

alignment of the table passed to general_tbl

outnm

character with the name of the tex file to generate and compile (e.g. define.tex)

orientation

character the page orientation in case a file is to be returned (can be either 'portrait' or 'landscape')

size

character with font size as for the table general_tbl

src

object that holds information regarding the source (e.g. get_log()$srce_nfo ), if NULL an attempt is made to get it from the environment

...

additional arguments passed to general_tbl

Value

a data frame, code for table or nothing in case a PDF file is created

Author(s)

Richard Hooijmaijers

Examples


xmpl   <- system.file("example/Attr.Template.xlsx",package = "amp.dm")
attrl  <- attr_xls(xmpl)
define_tbl(attrl)

amp.dm documentation built on March 13, 2026, 5:08 p.m.