| define_tbl | R Documentation |
This function creates the define.pdf file necessary for esubmission.
define_tbl(
attr = NULL,
ret = "dfrm",
capt = "Dataset define form",
align = "lp{3cm}lp{8cm}",
outnm = NULL,
orientation = "portrait",
size = "\\footnotesize",
src = NULL,
...
)
attr |
list with datasets attributes |
ret |
a character vector to define what kind of output should be returned (either "dfrm", "tbl", "file") |
capt |
character with the caption of the table |
align |
alignment of the table passed to general_tbl |
outnm |
character with the name of the tex file to generate and compile (e.g. define.tex) |
orientation |
character the page orientation in case a file is to be returned (can be either 'portrait' or 'landscape') |
size |
character with font size as for the table general_tbl |
src |
object that holds information regarding the source (e.g. |
... |
additional arguments passed to general_tbl |
a data frame, code for table or nothing in case a PDF file is created
Richard Hooijmaijers
xmpl <- system.file("example/Attr.Template.xlsx",package = "amp.dm")
attrl <- attr_xls(xmpl)
define_tbl(attrl)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.