powered by
This function creates the define.pdf file necessary for esubmission.
define_tbl( attr = NULL, ret = "dfrm", capt = "Dataset define form", align = "lp{3cm}lp{8cm}", outnm = NULL, orientation = "portrait", size = "\\footnotesize", src = NULL, ... )
a data frame, code for table or nothing in case a PDF file is created
list with datasets attributes
a character vector to define what kind of output should be returned (either "dfrm", "tbl", "file")
character with the caption of the table
alignment of the table passed to general_tbl
character with the name of the tex file to generate and compile (e.g. define.tex)
character the page orientation in case a file is to be returned (can be either 'portrait' or 'landscape')
character with font size as for the table general_tbl
object that holds information regarding the source (e.g. get_log()$srce_nfo ), if NULL an attempt is made to get it from the environment
get_log()$srce_nfo
additional arguments passed to general_tbl
Richard Hooijmaijers
xmpl <- system.file("example/Attr.Template.xlsx",package = "amp.dm") attrl <- attr_xls(xmpl) define_tbl(attrl)
Run the code above in your browser using DataLab