View source: R/flag_outliers.r
| flag_outliers | R Documentation |
This function creates a flag identifying the outliers in a vector
flag_outliers(var, type = "boxstat")
var |
numeric vector that should be checked for outliers |
type |
character with the type of test to perform for outliers (currently only the "boxstats" is available that uses the boxplot method) |
a numeric vector the same length as var with either 0 (no outlier) or 1 (outlier)
Richard Hooijmaijers
dfrm <- data.frame(a = 1:10, b = c(1:9,50))
flag_outliers(dfrm$a)
flag_outliers(dfrm$b)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.