Skip to contents

Get the current script name (either interactive Rstudio, markdown or batch script)

Usage

get_script(base = TRUE, noext = TRUE)

Arguments

base

logical indicating if the basename should be returned (without path)

noext

logical indicating if the file extension should be omitted

Value

character with the current script name

Author

Richard Hooijmaijers