| get_script | R Documentation |
Get the current script name (either interactive Rstudio, markdown or batch script)
get_script(base = TRUE, noext = TRUE)
base |
logical indicating if the basename should be returned (without path) |
noext |
logical indicating if the file extension should be omitted |
character with the current script name
Richard Hooijmaijers
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.