Learn R Programming

amp.dm (version 0.2.0)

get_script: Get the current script name (either interactive Rstudio, markdown or batch script)

Description

Get the current script name (either interactive Rstudio, markdown or batch script)

Usage

get_script(base = TRUE, noext = TRUE)

Value

character with the current script name

Arguments

base

logical indicating if the basename should be returned (without path)

noext

logical indicating if the file extension should be omitted

Author

Richard Hooijmaijers