Sets the read-only attribute for all files available within a folder
Source:R/make_readonly.r
make_readonly.RdThis function will change the file attributes so only read access is set
Details
This function will attempt to set a read-only attributes on files. This is either done through system commands
such as attrib for windows and chmod for linux (444). With the latter take into account possible issues
with (sudo) rights on files.
In case x is a directory, the function will set readonly attribute for all files in the folder (and recurse into all subfolders!).