In case tonum is TRUE, all variables will be made numeric and Inf values will be
set to NA (all NA values will be set to a dot). The rounding set in maxdig
will only be done in case tonum is set to TRUE. For xpt files, the name of the object to export is used as the name
of the dataset inside the xpt file (e.g. output_data(dfrm,xpt='dataset.xpt') will result in an xpt file named
'dataset.xpt' with one dataset named 'dfrm').