| plot_vars | R Documentation |
This function creates histograms for numeric values and barcharts for character or factor variables In case there are more then 10 unique values it will list the first 10 unique values in a 'text' plot
plot_vars(dfrm, vars = names(dfrm), ppp = 16, ...)
dfrm |
data frame that should be plotted |
vars |
character vector with the variables for which plots should be generated |
ppp |
number plots per page |
... |
additional arguments passed to |
a ggplot/patchwork object with all variables plotted visualized
Richard Hooijmaijers
plot_vars(Theoph)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.