session_tbl: Create information for R session

View source: R/session_tbl.r

session_tblR Documentation

Create information for R session

Description

This function creates a latex table or data frame with information from the R session (sessionInfo() and Sys.info())

Usage

session_tbl(
  ret = "tbl",
  capt = "Session info",
  align = "lp{8cm}",
  size = "\\footnotesize",
  ...
)

Arguments

ret

a character vector to define what kind of output should be returned (either "dfrm", "tbl", "file")

capt

character with the caption of the table (not used in case data frame is returned)

align

alignment of the table passed to general_tbl (not used in case data frame is returned)

size

character with font size as for the table general_tbl

...

additional arguments passed to general_tbl

Details

This function can be used to create a table with the most important information of a R session, the user that is running the R session and the current date/time

Value

a data frame, code for table or nothing in case a PDF file is created

Author(s)

Richard Hooijmaijers

Examples


session_tbl()

amp.dm documentation built on March 13, 2026, 5:08 p.m.