| session_tbl | R Documentation |
This function creates a latex table or data frame with information from the R session (sessionInfo() and Sys.info())
session_tbl(
ret = "tbl",
capt = "Session info",
align = "lp{8cm}",
size = "\\footnotesize",
...
)
ret |
a character vector to define what kind of output should be returned (either "dfrm", "tbl", "file") |
capt |
character with the caption of the table (not used in case data frame is returned) |
align |
alignment of the table passed to general_tbl (not used in case data frame is returned) |
size |
character with font size as for the table general_tbl |
... |
additional arguments passed to general_tbl |
This function can be used to create a table with the most important information of a R session, the user that is running the R session and the current date/time
a data frame, code for table or nothing in case a PDF file is created
Richard Hooijmaijers
session_tbl()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.