Learn R Programming

amp.dm (version 0.2.0)

session_tbl: Create information for R session

Description

This function creates a latex table or data frame with information from the R session (sessionInfo() and Sys.info())

Usage

session_tbl(
  ret = "tbl",
  capt = "Session info",
  align = "lp{8cm}",
  size = "\\footnotesize",
  ...
)

Value

a data frame, code for table or nothing in case a PDF file is created

Arguments

ret

a character vector to define what kind of output should be returned (either "dfrm", "tbl", "file")

capt

character with the caption of the table (not used in case data frame is returned)

align

alignment of the table passed to general_tbl (not used in case data frame is returned)

size

character with font size as for the table general_tbl

...

additional arguments passed to general_tbl

Author

Richard Hooijmaijers

Details

This function can be used to create a table with the most important information of a R session, the user that is running the R session and the current date/time

Examples

Run this code

session_tbl()

Run the code above in your browser using DataLab